@@ -59,17 +59,20 @@
                   #
                   legend = TRUE,
                   #
+                  .other_nma =
+                    c("netmeta.crossnma", "netmeta.gemtc", "netmeta.multinma"),
+                  #
                   .argslist.netmeta = argslist))
 }
 
 
 calcV <- function(x, sm) {
-  p2 <- (x$event2[1] + x$incr[1]) / (x$n2[1] + 2 * x$incr[1])
-  n2 <- x$n2[1] + 2 * x$incr[1]
+  p2 <- (x$event2[1] + x$incr2[1]) / (x$n2[1] + 2 * x$incr2[1])
+  n2 <- x$n2[1] + 2 * x$incr2[1]
   ##
   if (sm == "OR")
-    V <- matrix(1 / (x$event2[1] + x$incr[1]) +
-                1 / (x$n2[1] - x$event2[1] + x$incr[1]),
+    V <- matrix(1 / (x$event2[1] + x$incr2[1]) +
+                1 / (x$n2[1] - x$event2[1] + x$incr2[1]),
                 nrow = nrow(x), ncol = nrow(x))
   else if (sm == "RR")
     V <- matrix((1 - p2) / (n2 * p2),
@@ -83,18 +86,25 @@ calcV <- function(x, sm) {
   else if (sm == "MD")
     V <- matrix(x$sd2[1]^2 / x$n2[1],
                 nrow = nrow(x), ncol = nrow(x))
+  else if (sm == "SMD")
+    V <- matrix(1 / x$n2[1],
+                nrow = nrow(x), ncol = nrow(x))
   else if (sm == "IRR")
-    V <- matrix(1 / (x$event2[1] + x$incr[1]),
+    V <- matrix(1 / (x$event2[1] + x$incr2[1]),
                 nrow = nrow(x), ncol = nrow(x))
   else if (sm == "IRD")
-    V <- matrix((x$event2[1] + x$incr[1]) / x$time2[1]^2,
+    V <- matrix((x$event2[1] + x$incr2[1]) / x$time2[1]^2,
                 nrow = nrow(x), ncol = nrow(x))
   else if (sm == "IRSD")
     V <- matrix(0.25 / x$time2[1],
                 nrow = nrow(x), ncol = nrow(x))
-  ##
+  else if (nrow(x) == 1)
+    V <- as.matrix(x$seTE^2)
+  else
+    V <- diag(x$seTE^2)
+  #
   diag(V) <- x$seTE^2
-  ##
+  #
   V
 }
 
