@@ -201,9 +201,11 @@ netmetareg.netmeta <- function(x, covar = NULL,
   #
   dat[[covar.name]] <- covar
   #
-  if (!is.null(x$data$.n1) & !is.null(x$data$.n2)) { #netmeta is not exporting n1 and n2 for ORs
+  available.n <- available.events <- available.times <- available.sds <- FALSE
+  if (!is.null(x$data$.n1) & !is.null(x$data$.n2)) {
     dat$n1 <- x$data$.n1
     dat$n2 <- x$data$.n2
+    available.n <- TRUE
   }
   #
   if (!is.null(x$data$.mean1) & !is.null(x$data$.mean2)) {
@@ -214,50 +216,54 @@ netmetareg.netmeta <- function(x, covar = NULL,
   if (!is.null(x$data$.sd1) & !is.null(x$data$.sd2)) {
     dat$sd1 <- x$data$.sd1
     dat$sd2 <- x$data$.sd2
+    available.sds <- TRUE
+  }
+  #
+  if (!is.null(x$data$.event1) & !is.null(x$data$.event2)) {
+    dat$event1 <- x$data$.event1
+    dat$event2 <- x$data$.event2
+    available.events <- TRUE
   }
   #
   if (!is.null(x$data$.time1) & !is.null(x$data$.time2)) {
     dat$time1 <- x$data$.time1
     dat$time2 <- x$data$.time2
+    available.times <- TRUE
   }
-
-  # the logic above does not work because the following variables do not have .variable equivalents exported from netmeta. They are needed for the calcV function
-  if (!is.null(x$data$event1) & !is.null(x$data$event2)) {
-    dat$event1 <- ifelse(x$data$treat1==x$data$.treat1, x$data$event1, x$data$event2)
-    dat$event2 <- ifelse(x$data$treat2==x$data$.treat2, x$data$event2, x$data$event1)
-  }
-  if (!is.null(x$data$p1) & !is.null(x$data$p2)) {
-    dat$p1 <- ifelse(x$data$treat1==x$data$.treat1, x$data$p1, x$data$p2)
-    dat$p2 <- ifelse(x$data$treat2==x$data$.treat2, x$data$p2, x$data$p1)
-  }
-  if (!is.null(x$data$n1) & !is.null(x$data$n2)) {
-    dat$n1 <- ifelse(x$data$treat1==x$data$.treat1, x$data$n1, x$data$n2)
-    dat$n2 <- ifelse(x$data$treat2==x$data$.treat2, x$data$n2, x$data$n1)
-  }
-  if (!is.null(x$data$incr)) {
-    dat$incr <- x$data$incr
+  #
+  if (!is.null(x$data$.incr1) & !is.null(x$data$.incr2)) {
+    dat$incr1 <- x$data$.incr1
+    dat$incr2 <- x$data$.incr2
   }
   #
   dat <- dat[order(dat$studlab, dat$treat1, dat$treat2), , drop = FALSE]
   #
   keep <- logical(0)
   wo <- logical(0)
+  
+  # Check for constant covariate in reference treatment
   #
-  for (i in unique(dat$studlab)) {
-    d.i <- dat[dat$studlab == i, , drop = FALSE]
-    trts.i <- unique(sort(c(d.i$treat1, d.i$treat2)))
-    if (reference.group %in% trts.i)
-      ref.i <- reference.group
-    else
-      ref.i <- rev(trts.i)[1]
-    #
-    keep.i <- !(d.i$treat1 != ref.i & d.i$treat2 != ref.i)
-    wo.i <- d.i$treat1 == ref.i
-    #
-    keep <- c(keep, keep.i)
-    wo <- c(wo, wo.i)
+  if (consistency) {
+    if (length(unique(dat[dat$treat1 == reference.group |
+                          dat$treat2 == reference.group, covar.name])) == 1)
+      stop("Invalid reference treatment for interaction. Insufficient ",
+           "variation in observed covariate values for reference treatment.")
+    
+    for (i in unique(dat$studlab)) {
+      d.i <- dat[dat$studlab == i, , drop = FALSE]
+      trts.i <- unique(sort(c(d.i$treat1, d.i$treat2)))
+      if (reference.group %in% trts.i)
+        ref.i <- reference.group
+      else
+        ref.i <- rev(trts.i)[1]
+      #
+      keep.i <- !(d.i$treat1 != ref.i & d.i$treat2 != ref.i)
+      wo.i <- d.i$treat1 == ref.i
+      #
+      keep <- c(keep, keep.i)
+      wo <- c(wo, wo.i)
+    }
   }
-  #
   dat <- dat[keep, , drop = FALSE]
   #
   wo <- wo[keep]
@@ -270,6 +276,7 @@ netmetareg.netmeta <- function(x, covar = NULL,
     mean2.i <- dat$mean2
     sd2.i <- dat$sd2
     time2.i <- dat$time2
+    incr2.i <- dat$incr2
     #
     dat$treat2[wo] <- dat$treat1[wo]
     dat$event2[wo] <- dat$event1[wo]
@@ -277,6 +284,7 @@ netmetareg.netmeta <- function(x, covar = NULL,
     dat$mean2[wo] <- dat$mean1[wo]
     dat$sd2[wo] <- dat$sd1[wo]
     dat$time2[wo] <- dat$time1[wo]
+    dat$incr2[wo] <- dat$incr1[wo]
     #
     dat$treat1[wo] <- t2.i[wo]
     dat$event1[wo] <- e2.i[wo]
@@ -284,17 +292,16 @@ netmetareg.netmeta <- function(x, covar = NULL,
     dat$mean1[wo] <- mean2.i[wo]
     dat$sd1[wo] <- sd2.i[wo]
     dat$time1[wo] <- time2.i[wo]
+    dat$incr1[wo] <- incr2.i[wo]
   }
   #
   ncols1 <- ncol(dat)
   dat <- contrmat(dat, grp1 = "treat1", grp2 = "treat2")
-  ncols2 <- ncol(dat)
-  varnames <- names(dat)[(ncols1 + 1):ncols2]
-  #
   dat <- dat[order(dat$studlab), ]
+  trts.all <- names(dat)[(ncols1 + 1):ncol(dat)]
   #
-  trts.all <- varnames
-  trts <- varnames[-length(varnames)]
+  # Ensure that the reference treatment is correctly assigned
+  trts <- trts.all[trts.all != reference.group]
   
   
   #
@@ -322,7 +329,7 @@ netmetareg.netmeta <- function(x, covar = NULL,
       # colon which is in the same format as the independent. Helpful
       # for later extraction
       #
-      dat$nonref <- as.numeric(dat[[reference.group]] != 0)
+      dat$nonref <- as.numeric(dat[[make.names(reference.group)]] != 0)
       #
       formula.nmr_default <- # renamed for construction of manual matrix below
         as.formula(paste("~ 0 + ",
@@ -386,7 +393,12 @@ netmetareg.netmeta <- function(x, covar = NULL,
   #
   # Calculate Variance-Covariance matrix
   #
-  V <- bldiag(lapply(split(dat, dat$studlab), calcV, sm = sm))
+  if (available.n &
+      (available.events | available.times | (available.sds))) {
+    V <- bldiag(lapply(split(dat, dat$studlab), calcV, sm = sm))
+  }
+  else
+    V <- dat$seTE^2
   #
   suppressWarnings(
     res <-
