@@ -77,27 +77,7 @@
 #'   keep.samples = TRUE)
 #' ran1
 #' 
-#' rankogram(ran1$samples.random, pooled = "random")
-#' 
-#' \donttest{
-#' pw2 <- pairwise(treat = list(treatment1, treatment2, treatment3),
-#'   event = list(resp1, resp2, resp3), n = list(n1, n2, n3),
-#'   studlab = id, data = dat.linde2015, sm = "OR")
-#' #
-#' net2 <- netmeta(pw2, common = FALSE,
-#'   ref = "Placebo", small = "undesirable")
-#' 
-#' ran2 <- rankogram(net2, nsim = 100, common = FALSE,
-#'   keep.samples = TRUE)
-#' ran2
-#' 
-#' # Wrong ranking due to using the default,
-#' # i.e., argument 'small.values = "desirable".
-#' rankogram(ran2$samples.random, pooled = "random")
-#' # Correct ranking 
-#' rankogram(ran2$samples.random, pooled = "random",
-#'   small.values = "undesirable")
-#' }
+#' rankogram(ran1$samples.random)
 #'
 #' @rdname rankogram.default
 #' @method rankogram default
@@ -157,8 +137,11 @@ rankogram.default <- function(x, pooled = "unspecified",
   if (small.values == "undesirable")
     x <- -x
   #
-  sucras.common  <- ranking.matrix.common  <- cumrank.matrix.common  <- NULL
-  sucras.random <- ranking.matrix.random <- rank.cum.random <- NULL
+  sucras.common  <- ranking.matrix.common  <- cumrank.matrix.common <-
+    meanranks.common <- medianranks.common <- NULL
+  #
+  sucras.random <- ranking.matrix.random <- cumrank.matrix.random <-
+    meanranks.random <- medianranks.random <- NULL
   #
   if (common) {
     res.c <- rankings(x)
@@ -167,6 +150,9 @@ rankogram.default <- function(x, pooled = "unspecified",
     ranking.matrix.common <- res.c$rankogram
     cumrank.matrix.common <- res.c$cumrank
     #
+    meanranks.common <- res.c$meanranks
+    medianranks.common <- res.c$medianranks
+    #
     samples.common <- x
     nsim <- res.c$nsim
   }
@@ -176,7 +162,10 @@ rankogram.default <- function(x, pooled = "unspecified",
     #
     sucras.random <- res.r$sucras
     ranking.matrix.random <- res.r$rankogram
-    rank.cum.random <- res.r$cumrank
+    cumrank.matrix.random <- res.r$cumrank
+    #
+    meanranks.random <- res.r$meanranks
+    medianranks.random <- res.r$medianranks
     #
     samples.random <- x
     nsim <- res.r$nsim
@@ -192,12 +181,20 @@ rankogram.default <- function(x, pooled = "unspecified",
   res <- list(ranking.common = sucras.common,
               ranking.matrix.common = ranking.matrix.common,
               cumrank.matrix.common = cumrank.matrix.common,
+              #
+              meanranks.common = meanranks.common,
+              medianranks.common = medianranks.common,
+              #
               samples.common =
                 if (common & keep.samples) samples.common else NULL,
               #
               ranking.random = sucras.random,
               ranking.matrix.random = ranking.matrix.random,
-              cumrank.matrix.random = rank.cum.random,
+              cumrank.matrix.random = cumrank.matrix.random,
+              #
+              meanranks.random = meanranks.random,
+              medianranks.random = medianranks.random,
+              #
               samples.random =
                 if (random & keep.samples) samples.random else NULL,
               #
